@@ -12,9 +12,7 @@ sub new {
   
   my %options = @_;
   
-  my $build_dir = $options{build_dir};
-  
-  my $builder = SPVM::Builder->new(build_dir => $build_dir);
+  my $builder = SPVM::Builder->new(%options);
   
   $self->{builder} = $builder;
   
@@ -73,6 +71,10 @@ Options:
 
 A build directory.
 
+=item * C<optimize>
+
+The optimization level for the compiler.
+
 =back
 
 =head1 Instance Methods
