@@ -271,6 +271,7 @@ enum {
   SPVM_OP_C_ID_SET_CAPACITY,
   SPVM_OP_C_ID_STDERR,
   SPVM_OP_C_ID_CALLER,
+  SPVM_OP_C_ID_BREAK_POINT,
 };
 
 const char* const* SPVM_OP_C_ID_NAMES(void);
@@ -656,4 +657,6 @@ SPVM_OP* SPVM_OP_build_caller(SPVM_COMPILER* compiler, SPVM_OP* op_caller, SPVM_
 
 SPVM_OP* SPVM_OP_new_op_caller_info_type(SPVM_COMPILER* compiler, const char* file, int32_t line);
 
+SPVM_OP* SPVM_OP_build_break_point(SPVM_COMPILER* compiler, SPVM_OP* op_break_point);
+
 #endif
