@@ -828,10 +828,10 @@ sub generate_makefile_pl_file {
   my $resource = $self->resource;
   
   # Native make rule
-  my $make_rule_native = $self->native && !$resource ? "\$make_rule .= SPVM::Builder::Util::API::create_make_rule_native('$class_name');" : '';
+  my $make_rule_native = $self->native && !$resource ? "\$make_rule .= SPVM::Builder::Util::API::create_make_rule_native('$class_name', \$options);" : '';
   
   # Precompile make rule
-  my $make_rule_precompile = $self->precompile && !$resource ? "\$make_rule .= SPVM::Builder::Util::API::create_make_rule_precompile('$class_name');" : '';
+  my $make_rule_precompile = $self->precompile && !$resource ? "\$make_rule .= SPVM::Builder::Util::API::create_make_rule_precompile('$class_name', \$options);" : '';
 
   my $perl_class_rel_file = SPVM::Builder::Util::convert_class_name_to_rel_file($class_name, 'pm');
   $perl_class_rel_file =  $self->create_lib_rel_file($perl_class_rel_file);
@@ -863,6 +863,7 @@ use Getopt::Long 'GetOptions';
 GetOptions(
   'meta' => \\my \$meta,
   'no-build-spvm-modules' => \\my \$no_build_spvm_modules,
+  'optimize=s' => \\my \$optimize,
 );
 
 if (\$meta) {
@@ -920,6 +921,11 @@ sub MY::postamble {
     
     local \@INC = ('lib', \@INC);
     
+    my \$options = {};
+    if (defined \$optimize) {
+      \$options->{optimize} = \$optimize;
+    }
+    
     $make_rule_native
     $make_rule_precompile
   }
